# Palp

这是一个爬虫框架，教程请点击[文档](https://leviathangk.github.io/palp-doc/)

# 安装

```
pip install palp
```

# 创建项目

创建项目和爬虫都会去判断文件是否存在

```
palp create -p xxx
```

# 创建爬虫

创建爬虫时，会自动移动到 spiders 文件夹下（查找为 3 个深度）

```
palp create -s xxx 1
```